Auth bundle — Invenio 3.4.0a8 documentation

# Auth bundle

The auth bundle contains all modules related to account and access management, user profiles, session management and OAuth (provider and client)

Included modules:

- invenio-access

    - Role Based Access Control (RBAC) with object level permissions.

- invenio-accounts

    - User/role management, registration, password recovery, email verification, session theft protection, strong cryptographic hashing of passwords, hash migration, session activity tracking and CSRF protection of REST API via JSON Web Tokens.

- invenio-oauth2server

    - OAuth 2.0 Provider for REST API authentication via access tokens.

- invenio-oauthclient

    - User identity management and support for login via ORCID, GitHub, Google or other OAuth providers.

- invenio-userprofiles

    - User profiles for integration into registration forms.

The modules relies heavily on a suite of open source community projects:

- flask-security

- flask-login

- flask-principal

- flask-oauthlib

- passlib